Python Module Index — Personis 12.9 documentation

### Navigation

- index
- modules |
- Personis 12.9 documentation »

# Python Module Index

p

| p |
| `personis` |
| `personis.client` (Unix, Windows) | Client for the personis user model server
| `personis.client.util` |
| `personis.server` |
| `personis.server.active` |
| `personis.server.base` |
| `personis.server.cronserver` |
| `personis.server.ev_filters` |
| `personis.server.exceptions` |
| `personis.server.jsoncall` |
| `personis.server.mkmodel` |
| `personis.server.resolvers` |
| `personis.server.server` |
| `personis.server.subscription` |
| `personis.server.util` |

### Navigation

- index
- modules |
- Personis 12.9 documentation »